# eric7.Preferences.ConfigurationPages.NotificationsPage

Module implementing the Notifications configuration page.

### Global Attributes

None

### Classes

NotificationsPage | Class implementing the Notifications configuration page.

### Functions

create | Module function to create the configuration page.

## NotificationsPage

Class implementing the Notifications configuration page.

### Derived from

ConfigurationPageBase, Ui_NotificationsPage

### Class Attributes

None

### Class Methods

None

### Methods

NotificationsPage | Constructor
__moveNotification | Private slot to move the notification widget.
on_criticalBgButton_clicked | Private slot to set the background color of the critical notifications.
on_criticalDefaultButton_clicked | Private slot to reset the colors for critical notifications to their default values.
on_criticalFgButton_clicked | Private slot to set the foreground color of the critical notifications.
on_criticalResetButton_clicked | Private slot to reset the colors for critical notifications to their current values.
on_visualButton_clicked | Private slot to select the position visually.
on_warningBgButton_clicked | Private slot to set the background color of the warning notifications.
on_warningDefaultButton_clicked | Private slot to reset the colors for warning notifications to their default values.
on_warningFgButton_clicked | Private slot to set the foreground color of the warning notifications.
on_warningResetButton_clicked | Private slot to reset the colors for warning notifications to their current values.
save | Public slot to save the Notifications configuration.

### Static Methods

None

#### NotificationsPage (Constructor)

NotificationsPage()

Constructor

#### NotificationsPage.__moveNotification

__moveNotification()

Private slot to move the notification widget.

#### NotificationsPage.on_criticalBgButton_clicked

on_criticalBgButton_clicked()

Private slot to set the background color of the critical notifications.

#### NotificationsPage.on_criticalDefaultButton_clicked

on_criticalDefaultButton_clicked()

Private slot to reset the colors for critical notifications to their default values.

#### NotificationsPage.on_criticalFgButton_clicked

on_criticalFgButton_clicked()

Private slot to set the foreground color of the critical notifications.

#### NotificationsPage.on_criticalResetButton_clicked

on_criticalResetButton_clicked()

Private slot to reset the colors for critical notifications to their current values.

#### NotificationsPage.on_visualButton_clicked

on_visualButton_clicked(checked)

Private slot to select the position visually.

checked (bool)
  state of the button

#### NotificationsPage.on_warningBgButton_clicked

on_warningBgButton_clicked()

Private slot to set the background color of the warning notifications.

#### NotificationsPage.on_warningDefaultButton_clicked

on_warningDefaultButton_clicked()

Private slot to reset the colors for warning notifications to their default values.

#### NotificationsPage.on_warningFgButton_clicked

on_warningFgButton_clicked()

Private slot to set the foreground color of the warning notifications.

#### NotificationsPage.on_warningResetButton_clicked

on_warningResetButton_clicked()

Private slot to reset the colors for warning notifications to their current values.

#### NotificationsPage.save

save()

Public slot to save the Notifications configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up